PhiA numeric vector with the net Phi from Promethee.
vecWeightsA numeric vector with the weights for each criteria.
alternativesA character vector with alternatives names.
criteriasA character vector with criterias names.
datMatA matrix containing the data from criterias and alternatives.