An S4 class to store results from RPrometheeIVKernel.
PhiPlusA numeric vector with the PhiPlus result from Promethee.
PhiMinusA numeric vector with the PhiMinus result from Promethee.
IndexA numeric vector with the Index result from Promethee.
alternativesA character vector with alternatives names.
criteriasA character vector with criterias names.
datMatA matrix containing the data from criterias and alternatives.