PhiA numeric vector with the net Phi from Promethee.
SolutionThe solution resulting from the linear programming problem.
alternativesA character vector with alternatives names.
criteriasA character vector with criterias names.
datMatA matrix containing the data from criterias and alternatives.